@@ -10,6 +10,7 @@ use inspector::ResultInspector;
 use secrecy::ExposeSecret;
 use secrecy::SecretString;
 use serde::{de, ser};
+use serde_json as json;
 
 use crate::location::Location;
 use crate::output::Output;
@@ -218,30 +219,27 @@ impl Api {
 
     pub(crate) async fn set_owner(
         &self,
-        state: impl AsRef<v1::StateName>,
-        cluster: impl AsRef<v1::ClusterName>,
+        state: &v1::StateName,
+        cluster: &v1::ClusterName,
     ) -> ApiResult<v1::State> {
         let path = format!(
             "/states/{state}/owner/{cluster}",
-            state = state.as_ref(),
-            cluster = cluster.as_ref(),
+            state = state,
+            cluster = cluster,
         );
         self.put(path).await
     }
 
-    pub(crate) async fn unset_owner(
-        &self,
-        state: impl AsRef<v1::StateName>,
-    ) -> ApiResult<v1::State> {
-        let path = format!("/states/{state}/owner", state = state.as_ref());
+    pub(crate) async fn unset_owner(&self, state: &v1::StateName) -> ApiResult<v1::State> {
+        let path = format!("/states/{state}/owner", state = state);
         self.del(path).await
     }
 
     pub(crate) async fn issue_cluster_token(
         &self,
-        cluster: impl AsRef<v1::ClusterName>,
+        cluster: &v1::ClusterName,
     ) -> ApiResult<v1::ClusterToken> {
-        let path = format!("/clusters/{}/token", cluster.as_ref());
+        let path = format!("/clusters/{}/token", cluster);
         self.post::<_, _, (), _>(path, None).await
     }
 
@@ -425,9 +423,15 @@ trait ResponseExt: Sized {
         if status.is_server_error() {
             anyhow::bail!("Server error {}", status)
         }
+
         if status.is_client_error() {
-            anyhow::bail!("Client error {}", status)
+            let unknown_error = |_| anyhow::anyhow!("Unexpected client error: {}", status);
+            let err = json::from_slice::<v1::Error>(&bytes)
+                .map_or_else(unknown_error, anyhow::Error::from);
+
+            return Err(err);
         }
+
         Ok(bytes)
     }
 }
